@@ -21,7 +21,7 @@ log_output() {
 	log-output -t check-missing-firmware "$@"
 }
 
-# USB is special, and we don't want to take it all done:
+# USB is special, and we don't want to take it all down:
 get_usb_module() {
 	address="$1"
 	device="/sys/bus/usb/devices/$address"
@@ -408,8 +408,12 @@ while check_missing && ask_load_firmware; do
 	# remove and reload modules so they see the new firmware
 	for module in $modules; do
 		if ! nic_is_configured $module; then
-			log "removing and loading kernel module $module"
-			log_output modprobe -r $module || true
+			if [ "$module" == "iwlwifi" ]; then
+				# iwlmvm depends on iwlwifi and may be loaded, so unload it first
+				log_output modprobe -r iwlmvm iwlwifi || true
+			else
+				log_output modprobe -r $module || true
+			fi
 			log_output modprobe $module || true
 
 			# iterate to avoid dealing with multiplicity explicitly:
